<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Circle</name>
    <message>
        <location filename="../Circle.js" line="+71"/>
        <source>Circle Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Okręgi&quot;</translatorcomment>
        <translation>Narzędzia okręgu</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show circle tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Okręgi&quot;</translatorcomment>
        <translation>Wyświetla narzędzia okręgu</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Circle</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Okrąg</translatorcomment>
        <translation>&amp;Okrąg</translation>
    </message>
</context>
</TS>
